==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/languages/es_US.php <==
<?php

return [
    'Names' => [
        'ace' => 'acehnés',
        'alt' => 'altái meridional',
        'arp' => 'arapaho',
        'ars' => 'árabe najdi',
        'bax' => 'bamun',
        'bho' => 'bhojpuri',
        'bla' => 'siksika',
        'bua' => 'buriat',
        'dum' => 'neerlandés medieval',
        'enm' => 'inglés medieval',
        'eu' => 'euskera',
        'frm' => 'francés medieval',
        'gan' => 'gan (China)',
        'gmh' => 'alemán de la alta edad media',
        'grc' => 'griego antiguo',
        'gu' => 'gurayatí',
        'hil' => 'hiligainón',
        'hsn' => 'xiang (China)',
        'ht' => 'criollo haitiano',
        'inh' => 'ingusetio',
        'kab' => 'cabilio',
        'kbd' => 'kabardiano',
        'krc' => 'karachay-balkar',
        'lo' => 'lao',
        'lou' => 'creole de Luisiana',
        'lrc' => 'lorí del norte',
        'lus' => 'lushai',
        'mga' => 'irlandés medieval',
        'nd' => 'ndebele del norte',
        'nr' => 'ndebele meridional',
        'nso' => 'sotho septentrional',
        'rm' => 'romanche',
        'se' => 'sami del norte',
        'shu' => 'árabe chadiano',
        'sma' => 'sami meridional',
        'smn' => 'sami de Inari',
        'ss' => 'siswati',
        'st' => 'sesoto',
        'syr' => 'siriaco',
        'tet' => 'tetún',
        'tn' => 'setchwana',
        'tyv' => 'tuviniano',
        'tzm' => 'tamazight del Marruecos Central',
        'xal' => 'kalmyk',
    ],
    'LocalizedNames' => [
        'ar_001' => 'árabe estándar moderno',
        'nl_BE' => 'flamenco',
        'sw_CD' => 'swahili del Congo',
        'zh_Hans' => 'chino simplificado',
        'zh_Hant' => 'chino tradicional',
    ],
];

==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/languages/es_US.php <==
<?php

return [
    'Names' => [
        'ace' => 'acehnés',
        'alt' => 'altái meridional',
        'arp' => 'arapaho',
        'ars' => 'árabe najdi',
        'bax' => 'bamun',
        'bho' => 'bhojpuri',
        'bla' => 'siksika',
        'bua' => 'buriat',
        'clc' => 'chilcotín',
        'crj' => 'cree del sureste',
        'crl' => 'cree del noreste',
        'crm' => 'moose cree',
        'crr' => 'algonquian',
        'dum' => 'neerlandés medieval',
        'enm' => 'inglés medieval',
        'eu' => 'euskera',
        'frm' => 'francés medieval',
        'gan' => 'gan (China)',
        'gmh' => 'alemán de la alta edad media',
        'grc' => 'griego antiguo',
        'gu' => 'gurayatí',
        'hax' => 'haida del sur',
        'hil' => 'hiligainón',
        'hsn' => 'xiang (China)',
        'ht' => 'criollo haitiano',
        'ikt' => 'inuktitut del oeste de Canadá',
        'inh' => 'ingusetio',
        'kab' => 'cabilio',
        'krc' => 'karachay-balkar',
        'lo' => 'lao',
        'lou' => 'creole de Luisiana',
        'lrc' => 'lorí del norte',
        'lsm' => 'saamia',
        'mga' => 'irlandés medieval',
        'nd' => 'ndebele del norte',
        'nr' => 'ndebele meridional',
        'ojb' => 'ojibwa del noroeste',
        'ojw' => 'ojibwa del oeste',
        'pis' => 'pijín',
        'rm' => 'romanche',
        'se' => 'sami del norte',
        'shu' => 'árabe chadiano',
        'slh' => 'lushootseed del sur',
        'sma' => 'sami meridional',
        'smn' => 'sami de Inari',
        'ss' => 'siswati',
        'str' => 'straits salish',
        'syr' => 'siriaco',
        'tce' => 'tutchone del sur',
        'tet' => 'tetún',
        'ttm' => 'tutchone del norte',
        'tyv' => 'tuviniano',
        'wal' => 'wolayta',
    ],
    'LocalizedNames' => [
        'sw_CD' => 'swahili del Congo',
    ],
];
